@@ -1,4 +1,4 @@
-# Copyright 2003 (c) Roger Bivand
+# Copyright 2003-4 (c) Roger Bivand
 
 subset.polylist <- function(x, subset, fit.bbox=TRUE, ...) {
 	if (!inherits(x, "polylist")) stop("x not a polylist object")
@@ -6,6 +6,12 @@ subset.polylist <- function(x, subset, fit.bbox=TRUE, ...) {
 	if (length(x) != length(subset)) stop("x and subset different lengths")
 	res <- subset.default(x, subset)
 	attr(res, "region.id") <- subset.default(attr(x, "region.id"), subset)
+	old.ids <- 1:length(x)
+	new.ids <- match(old.ids, which(subset))
+	after <- new.ids[subset.default(attr(x, "after"), subset)]
+	pO <- order(after, na.last=FALSE)
+	attr(res, "after") <- after
+	attr(res, "plotOrder") <- pO
 	class(res) <- "polylist"
 	attr(res, "maplim") <- attr(x, "maplim")
 	if (fit.bbox) attr(res, "maplim") <- maplimFromBbox(res)
